@@ -1,13 +1,12 @@
-"""
-KASConnectRPCClient: Handles Connect RPC communication with the Key Access Service (KAS).
+"""KASConnectRPCClient: Handles Connect RPC communication with the Key Access Service (KAS).
 This class encapsulates all interactions with otdf_python_proto.
 """
 
 import logging
 
-import urllib3
+import httpx
 from otdf_python_proto.kas import kas_pb2
-from otdf_python_proto.kas.kas_pb2_connect import AccessServiceClient
+from otdf_python_proto.kas.kas_connect import AccessServiceClientSync
 
 from otdf_python.auth_headers import AuthHeaders
 
@@ -15,45 +14,78 @@ from .sdk_exceptions import SDKException
 
 
 class KASConnectRPCClient:
-    """
-    Handles Connect RPC communication with KAS service using otdf_python_proto.
-    """
+    """Handles Connect RPC communication with KAS service using otdf_python_proto."""
 
     def __init__(self, use_plaintext=False, verify_ssl=True):
-        """
-        Initialize the Connect RPC client.
+        """Initialize the Connect RPC client.
 
         Args:
             use_plaintext: Whether to use plaintext (HTTP) connections
             verify_ssl: Whether to verify SSL certificates
+
         """
         self.use_plaintext = use_plaintext
         self.verify_ssl = verify_ssl
+        self._http_client = None
+
+    def __enter__(self):
+        """Enter context manager and create HTTP client."""
+        self._http_client = self._create_http_client()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """Exit context manager and close HTTP client."""
+        self.close()
+
+    def close(self):
+        """Close HTTP client and release resources.
+
+        This method should be called when the client is no longer needed
+        to properly clean up resources. It's also called automatically
+        when using the client as a context manager.
+        """
+        if self._http_client is not None:
+            self._http_client.close()
+            self._http_client = None
 
     def _create_http_client(self):
-        """
-        Create HTTP client with SSL verification configuration.
+        """Create HTTP client with SSL verification configuration.
 
         Returns:
-            urllib3.PoolManager configured for SSL verification settings
+            httpx.Client configured for SSL verification settings
+
         """
         if self.verify_ssl:
             logging.info("Using SSL verification enabled HTTP client")
-            return urllib3.PoolManager()
+            return httpx.Client()
         else:
             logging.info("Using SSL verification disabled HTTP client")
-            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
-            return urllib3.PoolManager(cert_reqs="CERT_NONE")
+            return httpx.Client(verify=False)
+
+    def _get_http_client(self):
+        """Get HTTP client, creating one if needed for backward compatibility.
+
+        Returns:
+            httpx.Client instance
+
+        """
+        if self._http_client is None:
+            logging.warning(
+                "KASConnectRPCClient is being used without a context manager. "
+                "Consider using 'with KASConnectRPCClient(...) as client:' to ensure proper resource cleanup."
+            )
+            self._http_client = self._create_http_client()
+        return self._http_client
 
     def _prepare_connect_rpc_url(self, kas_url):
-        """
-        Prepare the base URL for Connect RPC client.
+        """Prepare the base URL for Connect RPC client.
 
         Args:
             kas_url: The normalized KAS URL
 
         Returns:
             Base URL for Connect RPC client (without /kas suffix)
+
         """
         connect_rpc_base_url = kas_url
         # Remove /kas suffix, if present
@@ -61,14 +93,14 @@ class KASConnectRPCClient:
         return connect_rpc_base_url
 
     def _prepare_auth_headers(self, access_token):
-        """
-        Prepare authentication headers if access token is available.
+        """Prepare authentication headers if access token is available.
 
         Args:
             access_token: Bearer token for authentication
 
         Returns:
             Dictionary with authentication headers or None
+
         """
         if access_token:
             auth_headers = AuthHeaders(
@@ -79,8 +111,7 @@ class KASConnectRPCClient:
         return None
 
     def get_public_key(self, normalized_kas_url, kas_info, access_token=None):
-        """
-        Get KAS public key using Connect RPC.
+        """Get KAS public key using Connect RPC.
 
         Args:
             normalized_kas_url: The normalized KAS URL
@@ -89,6 +120,7 @@ class KASConnectRPCClient:
 
         Returns:
             Updated kas_info with public_key and kid
+
         """
         logging.info(
             f"KAS Connect RPC client settings for public key retrieval: "
@@ -96,8 +128,6 @@ class KASConnectRPCClient:
             f"kas_url={kas_info.url}"
         )
 
-        http_client = self._create_http_client()
-
         try:
             connect_rpc_base_url = self._prepare_connect_rpc_url(normalized_kas_url)
 
@@ -106,9 +136,13 @@ class KASConnectRPCClient:
                 f"for public key retrieval"
             )
 
-            # Create Connect RPC client with configured HTTP client using Connect protocol
-            # Note: gRPC protocol is not supported with urllib3, use default Connect protocol
-            client = AccessServiceClient(connect_rpc_base_url, http_client=http_client)
+            # Get or create HTTP client
+            http_client = self._get_http_client()
+
+            # Create Connect RPC client with configured HTTP client
+            client = AccessServiceClientSync(
+                address=connect_rpc_base_url, session=http_client
+            )
 
             # Create public key request
             algorithm = getattr(kas_info, "algorithm", "") or ""
@@ -119,10 +153,10 @@ class KASConnectRPCClient:
             )
 
             # Prepare headers with authentication if available
-            extra_headers = self._prepare_auth_headers(access_token)
+            headers = self._prepare_auth_headers(access_token)
 
             # Make the public key call with authentication headers
-            response = client.public_key(request, extra_headers=extra_headers)
+            response = client.public_key(request, headers=headers)
 
             # Update kas_info with response
             kas_info.public_key = response.public_key
@@ -138,13 +172,12 @@ class KASConnectRPCClient:
                 f"Connect RPC public key request failed: {type(e).__name__}: {e}"
             )
             logging.error(f"Full traceback: {error_details}")
-            raise SDKException(f"Connect RPC public key request failed: {e}")
+            raise SDKException(f"Connect RPC public key request failed: {e}") from e
 
     def unwrap_key(
         self, normalized_kas_url, key_access, signed_token, access_token=None
     ):
-        """
-        Unwrap a key using Connect RPC.
+        """Unwrap a key using Connect RPC.
 
         Args:
             normalized_kas_url: The normalized KAS URL
@@ -154,6 +187,7 @@ class KASConnectRPCClient:
 
         Returns:
             Unwrapped key bytes from the response
+
         """
         logging.info(
             f"KAS Connect RPC client settings for unwrap: "
@@ -161,8 +195,6 @@ class KASConnectRPCClient:
             f"kas_url={key_access.url}"
         )
 
-        http_client = self._create_http_client()
-
         try:
             kas_service_url = self._prepare_connect_rpc_url(normalized_kas_url)
 
@@ -170,8 +202,13 @@ class KASConnectRPCClient:
                 f"Creating Connect RPC client for base URL: {kas_service_url}, for unwrap"
             )
 
-            # Note: gRPC protocol is not supported with urllib3, use default Connect protocol
-            client = AccessServiceClient(kas_service_url, http_client=http_client)
+            # Get or create HTTP client
+            http_client = self._get_http_client()
+
+            # Create Connect RPC client with configured HTTP client
+            client = AccessServiceClientSync(
+                address=kas_service_url, session=http_client
+            )
 
             # Create rewrap request
             request = kas_pb2.RewrapRequest(
@@ -182,10 +219,10 @@ class KASConnectRPCClient:
             logging.info(f"Connect RPC signed token: {signed_token}")
 
             # Prepare headers with authentication if available
-            extra_headers = self._prepare_auth_headers(access_token)
+            headers = self._prepare_auth_headers(access_token)
 
             # Make the rewrap call with authentication headers
-            response = client.rewrap(request, extra_headers=extra_headers)
+            response = client.rewrap(request, headers=headers)
 
             # Extract the entity wrapped key from v2 response structure
             # The v2 response has responses[] array with results[] for each policy
@@ -210,4 +247,4 @@ class KASConnectRPCClient:
 
         except Exception as e:
             logging.error(f"Connect RPC rewrap failed: {e}")
-            raise SDKException(f"Connect RPC rewrap failed: {e}")
+            raise SDKException(f"Connect RPC rewrap failed: {e}") from e
