@@ -1,5 +1,4 @@
-from otdf_python.asym_decryption import AsymDecryption
-from otdf_python.asym_encryption import AsymEncryption
+from otdf_python.asym_crypto import AsymDecryption, AsymEncryption
 from tests.mock_crypto import generate_rsa_keypair
 
 
